==> tv_8.2201-2509122314.zip: dyn/ru/bitel/bgbilling/modules/tv/dyn/seventhsky/ipb/GetCustomersResponse.java <==

package ru.bitel.bgbilling.modules.tv.dyn.seventhsky.ipb;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.datatype.XMLGregorianCalendar;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="customers">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;sequence>
 *                   &lt;element name="customer" maxOccurs="unbounded">
 *                     &lt;complexType>
 *                       &lt;complexContent>
 *                         &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                           &lt;sequence>
 *                             &lt;element name="customerID" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *                             &lt;element name="terminalID" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *                             &lt;element name="tariffID" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *                             &lt;element name="startDate" type="{http://www.w3.org/2001/XMLSchema}dateTime"/>
 *                             &lt;element name="endDate" type="{http://www.w3.org/2001/XMLSchema}dateTime" minOccurs="0"/>
 *                           &lt;/sequence>
 *                         &lt;/restriction>
 *                       &lt;/complexContent>
 *                     &lt;/complexType>
 *                   &lt;/element>
 *                 &lt;/sequence>
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "customers"
})
@XmlRootElement(name = "getCustomersResponse")
public class GetCustomersResponse {

    @XmlElement(required = true)
    protected GetCustomersResponse.Customers customers;

    /**
     * Gets the value of the customers property.
     * 
     * @return
     *     possible object is
     *     {@link GetCustomersResponse.Customers }
     *     
     */
    public GetCustomersResponse.Customers getCustomers() {
        return customers;
    }

    /**
     * Sets the value of the customers property.
     * 
     * @param value
     *     allowed object is
     *     {@link GetCustomersResponse.Customers }
     *     
     */
    public void setCustomers(GetCustomersResponse.Customers value) {
        this.customers = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element name="customer" maxOccurs="unbounded">
     *           &lt;complexType>
     *             &lt;complexContent>
     *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *                 &lt;sequence>
     *                   &lt;element name="customerID" type="{http://www.w3.org/2001/XMLSchema}int"/>
     *                   &lt;element name="terminalID" type="{http://www.w3.org/2001/XMLSchema}int"/>
     *                   &lt;element name="tariffID" type="{http://www.w3.org/2001/XMLSchema}int"/>
     *                   &lt;element name="startDate" type="{http://www.w3.org/2001/XMLSchema}dateTime"/>
     *                   &lt;element name="endDate" type="{http://www.w3.org/2001/XMLSchema}dateTime" minOccurs="0"/>
     *                 &lt;/sequence>
     *               &lt;/restriction>
     *             &lt;/complexContent>
     *           &lt;/complexType>
     *         &lt;/element>
     *       &lt;/sequence>
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "customer"
    })
    public static class Customers {

        @XmlElement(required = true)
        protected List<GetCustomersResponse.Customers.Customer> customer;

        /**
         * Gets the value of the customer property.
         * 
         * <p>
         * This accessor method returns a reference to the live list,
         * not a snapshot. Therefore any modification you make to the
         * returned list will be present inside the JAXB object.
         * This is why there is not a <CODE>set</CODE> method for the customer property.
         * 
         * <p>
         * For example, to add a new item, do as follows:
         * <pre>
         *    getCustomer().add(newItem);
         * </pre>
         * 
         * 
         * <p>
         * Objects of the following type(s) are allowed in the list
         * {@link GetCustomersResponse.Customers.Customer }
         * 
         * 
         */
        public List<GetCustomersResponse.Customers.Customer> getCustomer() {
            if (customer == null) {
                customer = new ArrayList<GetCustomersResponse.Customers.Customer>();
            }
            return this.customer;
        }


        /**
         * <p>Java class for anonymous complex type.
         * 
         * <p>The following schema fragment specifies the expected content contained within this class.
         * 
         * <pre>
         * &lt;complexType>
         *   &lt;complexContent>
         *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
         *       &lt;sequence>
         *         &lt;element name="customerID" type="{http://www.w3.org/2001/XMLSchema}int"/>
         *         &lt;element name="terminalID" type="{http://www.w3.org/2001/XMLSchema}int"/>
         *         &lt;element name="tariffID" type="{http://www.w3.org/2001/XMLSchema}int"/>
         *         &lt;element name="startDate" type="{http://www.w3.org/2001/XMLSchema}dateTime"/>
         *         &lt;element name="endDate" type="{http://www.w3.org/2001/XMLSchema}dateTime" minOccurs="0"/>
         *       &lt;/sequence>
         *     &lt;/restriction>
         *   &lt;/complexContent>
         * &lt;/complexType>
         * </pre>
         * 
         * 
         */
        @XmlAccessorType(XmlAccessType.FIELD)
        @XmlType(name = "", propOrder = {
            "customerID",
            "terminalID",
            "tariffID",
            "startDate",
            "endDate"
        })
        public static class Customer {

            protected int customerID;
            protected int terminalID;
            protected int tariffID;
            @XmlElement(required = true)
            @XmlSchemaType(name = "dateTime")
            protected XMLGregorianCalendar startDate;
            @XmlSchemaType(name = "dateTime")
            protected XMLGregorianCalendar endDate;

            /**
             * Gets the value of the customerID property.
             * 
             */
            public int getCustomerID() {
                return customerID;
            }

            /**
             * Sets the value of the customerID property.
             * 
             */
            public void setCustomerID(int value) {
                this.customerID = value;
            }

            /**
             * Gets the value of the terminalID property.
             * 
             */
            public int getTerminalID() {
                return terminalID;
            }

            /**
             * Sets the value of the terminalID property.
             * 
             */
            public void setTerminalID(int value) {
                this.terminalID = value;
            }

            /**
             * Gets the value of the tariffID property.
             * 
             */
            public int getTariffID() {
                return tariffID;
            }

            /**
             * Sets the value of the tariffID property.
             * 
             */
            public void setTariffID(int value) {
                this.tariffID = value;
            }

            /**
             * Gets the value of the startDate property.
             * 
             * @return
             *     possible object is
             *     {@link XMLGregorianCalendar }
             *     
             */
            public XMLGregorianCalendar getStartDate() {
                return startDate;
            }

            /**
             * Sets the value of the startDate property.
             * 
             * @param value
             *     allowed object is
             *     {@link XMLGregorianCalendar }
             *     
             */
            public void setStartDate(XMLGregorianCalendar value) {
                this.startDate = value;
            }

            /**
             * Gets the value of the endDate property.
             * 
             * @return
             *     possible object is
             *     {@link XMLGregorianCalendar }
             *     
             */
            public XMLGregorianCalendar getEndDate() {
                return endDate;
            }

            /**
             * Sets the value of the endDate property.
             * 
             * @param value
             *     allowed object is
             *     {@link XMLGregorianCalendar }
             *     
             */
            public void setEndDate(XMLGregorianCalendar value) {
                this.endDate = value;
            }

        }

    }

}

==> tv_10.2504-2509150239.zip: dyn/ru/bitel/bgbilling/modules/tv/dyn/seventhsky/ipb/GetCustomersResponse.java <==

package ru.bitel.bgbilling.modules.tv.dyn.seventhsky.ipb;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlSchemaType;
import jakarta.xml.bind.annotation.XmlType;
import javax.xml.datatype.XMLGregorianCalendar;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="customers">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;sequence>
 *                   &lt;element name="customer" maxOccurs="unbounded">
 *                     &lt;complexType>
 *                       &lt;complexContent>
 *                         &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                           &lt;sequence>
 *                             &lt;element name="customerID" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *                             &lt;element name="terminalID" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *                             &lt;element name="tariffID" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *                             &lt;element name="startDate" type="{http://www.w3.org/2001/XMLSchema}dateTime"/>
 *                             &lt;element name="endDate" type="{http://www.w3.org/2001/XMLSchema}dateTime" minOccurs="0"/>
 *                           &lt;/sequence>
 *                         &lt;/restriction>
 *                       &lt;/complexContent>
 *                     &lt;/complexType>
 *                   &lt;/element>
 *                 &lt;/sequence>
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "customers"
})
@XmlRootElement(name = "getCustomersResponse")
public class GetCustomersResponse {

    @XmlElement(required = true)
    protected GetCustomersResponse.Customers customers;

    /**
     * Gets the value of the customers property.
     * 
     * @return
     *     possible object is
     *     {@link GetCustomersResponse.Customers }
     *     
     */
    public GetCustomersResponse.Customers getCustomers() {
        return customers;
    }

    /**
     * Sets the value of the customers property.
     * 
     * @param value
     *     allowed object is
     *     {@link GetCustomersResponse.Customers }
     *     
     */
    public void setCustomers(GetCustomersResponse.Customers value) {
        this.customers = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element name="customer" maxOccurs="unbounded">
     *           &lt;complexType>
     *             &lt;complexContent>
     *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *                 &lt;sequence>
     *                   &lt;element name="customerID" type="{http://www.w3.org/2001/XMLSchema}int"/>
     *                   &lt;element name="terminalID" type="{http://www.w3.org/2001/XMLSchema}int"/>
     *                   &lt;element name="tariffID" type="{http://www.w3.org/2001/XMLSchema}int"/>
     *                   &lt;element name="startDate" type="{http://www.w3.org/2001/XMLSchema}dateTime"/>
     *                   &lt;element name="endDate" type="{http://www.w3.org/2001/XMLSchema}dateTime" minOccurs="0"/>
     *                 &lt;/sequence>
     *               &lt;/restriction>
     *             &lt;/complexContent>
     *           &lt;/complexType>
     *         &lt;/element>
     *       &lt;/sequence>
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "customer"
    })
    public static class Customers {

        @XmlElement(required = true)
        protected List<GetCustomersResponse.Customers.Customer> customer;

        /**
         * Gets the value of the customer property.
         * 
         * <p>
         * This accessor method returns a reference to the live list,
         * not a snapshot. Therefore any modification you make to the
         * returned list will be present inside the JAXB object.
         * This is why there is not a <CODE>set</CODE> method for the customer property.
         * 
         * <p>
         * For example, to add a new item, do as follows:
         * <pre>
         *    getCustomer().add(newItem);
         * </pre>
         * 
         * 
         * <p>
         * Objects of the following type(s) are allowed in the list
         * {@link GetCustomersResponse.Customers.Customer }
         * 
         * 
         */
        public List<GetCustomersResponse.Customers.Customer> getCustomer() {
            if (customer == null) {
                customer = new ArrayList<GetCustomersResponse.Customers.Customer>();
            }
            return this.customer;
        }


        /**
         * <p>Java class for anonymous complex type.
         * 
         * <p>The following schema fragment specifies the expected content contained within this class.
         * 
         * <pre>
         * &lt;complexType>
         *   &lt;complexContent>
         *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
         *       &lt;sequence>
         *         &lt;element name="customerID" type="{http://www.w3.org/2001/XMLSchema}int"/>
         *         &lt;element name="terminalID" type="{http://www.w3.org/2001/XMLSchema}int"/>
         *         &lt;element name="tariffID" type="{http://www.w3.org/2001/XMLSchema}int"/>
         *         &lt;element name="startDate" type="{http://www.w3.org/2001/XMLSchema}dateTime"/>
         *         &lt;element name="endDate" type="{http://www.w3.org/2001/XMLSchema}dateTime" minOccurs="0"/>
         *       &lt;/sequence>
         *     &lt;/restriction>
         *   &lt;/complexContent>
         * &lt;/complexType>
         * </pre>
         * 
         * 
         */
        @XmlAccessorType(XmlAccessType.FIELD)
        @XmlType(name = "", propOrder = {
            "customerID",
            "terminalID",
            "tariffID",
            "startDate",
            "endDate"
        })
        public static class Customer {

            protected int customerID;
            protected int terminalID;
            protected int tariffID;
            @XmlElement(required = true)
            @XmlSchemaType(name = "dateTime")
            protected XMLGregorianCalendar startDate;
            @XmlSchemaType(name = "dateTime")
            protected XMLGregorianCalendar endDate;

            /**
             * Gets the value of the customerID property.
             * 
             */
            public int getCustomerID() {
                return customerID;
            }

            /**
             * Sets the value of the customerID property.
             * 
             */
            public void setCustomerID(int value) {
                this.customerID = value;
            }

            /**
             * Gets the value of the terminalID property.
             * 
             */
            public int getTerminalID() {
                return terminalID;
            }

            /**
             * Sets the value of the terminalID property.
             * 
             */
            public void setTerminalID(int value) {
                this.terminalID = value;
            }

            /**
             * Gets the value of the tariffID property.
             * 
             */
            public int getTariffID() {
                return tariffID;
            }

            /**
             * Sets the value of the tariffID property.
             * 
             */
            public void setTariffID(int value) {
                this.tariffID = value;
            }

            /**
             * Gets the value of the startDate property.
             * 
             * @return
             *     possible object is
             *     {@link XMLGregorianCalendar }
             *     
             */
            public XMLGregorianCalendar getStartDate() {
                return startDate;
            }

            /**
             * Sets the value of the startDate property.
             * 
             * @param value
             *     allowed object is
             *     {@link XMLGregorianCalendar }
             *     
             */
            public void setStartDate(XMLGregorianCalendar value) {
                this.startDate = value;
            }

            /**
             * Gets the value of the endDate property.
             * 
             * @return
             *     possible object is
             *     {@link XMLGregorianCalendar }
             *     
             */
            public XMLGregorianCalendar getEndDate() {
                return endDate;
            }

            /**
             * Sets the value of the endDate property.
             * 
             * @param value
             *     allowed object is
             *     {@link XMLGregorianCalendar }
             *     
             */
            public void setEndDate(XMLGregorianCalendar value) {
                this.endDate = value;
            }

        }

    }

}
